#include <iostream>
#include <fstream>
#include <vector>
#include <algorithm>
#include <utility>
#include <map>
#include <climits>

using namespace std;

typedef unsigned long ulong;
typedef pair<long, long> P;


template <typename P>
struct IntervalTree {
    P *t;

    IntervalTree(long MAXN) { t = new P[4*MAXN]; };
    ~IntervalTree() { delete[] t; };

    P combine (P a, P b) {
        if (a.first > b.first)
            return a;
        if (b.first > a.first)
            return b;
        return make_pair(a.first, a.second + b.second);
    }

    void build (int a[], int v, int tl, int tr) {
        if (tl == tr)
            t[v] = make_pair(a[tl], 1);
        else {
            int tm = (tl + tr) / 2;
            build (a, v*2, tl, tm);
            build (a, v*2+1, tm+1, tr);
            t[v] = combine(t[v*2], t[v*2+1]);
        }
    }


    // ToDo: use different inf
    P get_max(int v, int tl, int tr, int l, int r) {
        if (l > r)
            return make_pair (-0, 0);
        if (l == tl && r == tr)
            return t[v];
        int tm = (tl + tr) / 2;
        return combine(
                       get_max(v*2, tl, tm, l, min(r, tm)),
                       get_max(v*2+1, tm+1, tr, max(l, tm+1), r)
                       );
    }

    void update(int v, int tl, int tr, int pos, int new_val) {
        if (tl == tr)
            t[v] = make_pair(new_val, 1);
        else {
            int tm = (tl+ tr) / 2;
            if (pos <= tm)
                update(v*2, tl, tm, pos, new_val);
            else
                update(v*2+1, tm+1, tr, pos, new_val);
            t[v] = combine(t[v*2], t[v*2+1]);
        }
    }

    long sum(int v, int tl, int tr, int l, int r) {
        if (l > r)
            return 0;
        if (l == tl && r == tr)
            return t[v];
        int tm = (tl + tr) / 2;
        return sum(v*2, tl, tm, l, min(r, tm)) +
                sum(v*2+1, tm+1, tr, max(l, tm+1), r);
    }
};


int main()
{
    ifstream fin("delivery.in");
    int T, P;
    unsigned long long N, M, F;
    unsigned long long *arr;
    unsigned long long num1, num2, total, ind, step;

    fin >> T;
    for (int i = 0; i < T; ++i) {
        fin >> N >> M >> F >> P;
        num1 = 0;
        num2 = 0;
        ind = 0;
        total = 0;

        if (P > 0) {

            arr = new unsigned long long[P];
            for (int j = 0; j < P; ++j) {
                fin >> arr[j];
            }

            while ((total < F) && (ind < P)) {
                if (ind == 0) {
                    total += 4*M*arr[ind] - 1;
                } else {
                    total += 4*M*(arr[ind] - arr[ind-1]) - 1;

                }
                ind++;
            }

            if (total > F) {
                total -= 4*M*(arr[ind] - arr[ind-1]) - 1;
                ind--;
            }
        }
        num1 = ind;
        step = (F - total) / (4*M);
        num1 += step;
        total += 4*M*step;

        num2 = (F - total) / 4;

        cout << (num1+1) << " " << num2+1 << endl;
        delete[] arr;
    }

    return 0;
}
